﻿using System.Collections.ObjectModel;
using System.ComponentModel.Composition;
using System.Windows;
using System.Windows.Controls;
using MainMenuModule.Model;
using Microsoft.Practices.Prism.Commands;
using Microsoft.Practices.Prism.ViewModel;

namespace PrismMEF1.MainMenuModule.ViewModels
{
    /// <summary>
    /// 뷰 모델 익스포트
    /// </summary>
    [Export]
    public class MainMenuViewModel : NotificationObject
    {
        string messageData;
        /// <summary>
        /// 메시지 데이터
        /// </summary>
        public string MessageData 
        {
            get
            {
                return messageData;
            }
            set
            {
                if (messageData != value)
                {
                    messageData = value;
                    //프리즘에서 제공하는 프로퍼티 체인지 이벤트
                    RaisePropertyChanged(() => this.MessageData);
                }
            }
        }

        ObservableCollection<string> messageCollection;
        /// <summary>
        /// 메시지 컬렉션
        /// </summary>
        public ObservableCollection<string> MessageCollection
        {
            get
            {
                return messageCollection;
            }
            set
            {
                if (messageCollection != value)
                {
                    messageCollection = value;
                    RaisePropertyChanged(() => this.MessageCollection);
                }
            }
        }

        private MenuModel mainMenu;
        /// <summary>
        /// 메뉴 모델
        /// </summary>
        public MenuModel MainMenu
        {
            get
            {
                return mainMenu;
            }
            set
            {
                mainMenu = value;
                RaisePropertyChanged(() => this.MainMenu);
            }
        }

        /// <summary>
        /// 임포트 컨트스럭처 - 익스포트/임포트시에 실행되는 생성자
        /// </summary>
        /// <param name="menuModel"></param>
        [ImportingConstructor]
        public MainMenuViewModel(MenuModel menuModel)
        {
            MessageCollection = new ObservableCollection<string>();
            //임포트 받은 메뉴 모델을 프로퍼티에 연결
            this.MainMenu = menuModel;
        }

        /// <summary>
        /// 디자인 타임 생성자
        /// </summary>
        public MainMenuViewModel()
        {
            this.MainMenu = new MenuModel();
        }

        DelegateCommand<object> menuSelect;
        /// <summary>
        /// 메뉴 선택 커맨드
        /// </summary>
        public DelegateCommand<object> MenuSelect
        { 
            get
            {
                if (menuSelect == null)
                {
                    menuSelect = new DelegateCommand<object>(obj =>
                    {
                        ListBox lb = obj as ListBox;
                        if (lb != null && lb.SelectedItem != null)
                        {
                            var item = lb.SelectedItem as string;
                            MessageBox.Show(item);
                        }
                    }
                    );
                }

                return menuSelect;
            }
        }

        DelegateCommand<object> menuAdd;
        /// <summary>
        /// 메뉴 추가 커맨드
        /// </summary>
        public DelegateCommand<object> MenuAdd
        {
            get
            {
                if (menuAdd == null)
                {
                    menuAdd = new DelegateCommand<object>(obj =>
                    {
                        var cnt = MainMenu.MenuCollection.Count;
                        var menu = "NewMenu" + cnt.ToString();
                        MainMenu.Adding(menu);
                    }
                    );
                }

                return menuAdd;
            }
        }

        DelegateCommand<object> menuRemove;
        /// <summary>
        /// 메뉴 삭제 커맨드
        /// </summary>
        public DelegateCommand<object> MenuRemove
        {
            get
            {
                if (menuRemove == null)
                {
                    menuRemove = new DelegateCommand<object>(obj =>
                    {
                        ListBox lb = obj as ListBox;
                        if (lb != null && lb.SelectedItem != null)
                        {
                            var menu = lb.SelectedItem as string;
                            MainMenu.Removing(menu);
                        }
                    }
                    );
                }

                return menuRemove;
            }
        }
    }
}
